@@ -5,6 +5,9 @@ mod table;
 pub use table::Table;
 pub use table::TableError;
 
+mod parse_expression;
+pub use parse_expression::ParseExpression;
+
 mod parse_tree;
 pub use parse_tree::ParseTree;
 pub use parse_tree::RawColumn;
@@ -20,6 +23,9 @@ pub use planned_statement::Plan;
 pub use planned_statement::PlannedCommon;
 pub use planned_statement::PlannedStatement;
 
+mod query_result;
+pub use query_result::QueryResult;
+
 mod query_tree;
 pub use query_tree::CommandType;
 pub use query_tree::JoinType;
